.. _drifts:

*********************************************
Particle drifts (`plasmapy.formulary.drifts`)
*********************************************

.. currentmodule:: plasmapy.formulary.drifts

.. automodapi:: plasmapy.formulary.drifts


Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/ExB_drift
